@@ -3,7 +3,13 @@ from typer.main import Typer
 import typer
 from typing import Optional
 import jmespath
+import random
+import time
 from rich.layout import Layout
+from rich.live import Live
+from rich.table import Table
+
+
 
 console = get_rich_console()
 
@@ -36,19 +42,40 @@ class BalconyServiceSummarizer(BaseBalconyApp,
     def get_cli_app(self, *args, **kwargs) -> typer.main.Typer:
         app = typer.Typer(no_args_is_help=True)
         
+        
+        def generate_table() -> Table:
+            """Make a new table."""
+            table = Table()
+            table.add_column("ID")
+            table.add_column("Value")
+            table.add_column("Status")
+
+            for row in range(random.randint(2, 6)):
+                value = random.random() * 100
+                table.add_row(
+                    f"{row}", f"{value:3.2f}", "[red]ERROR" if value < 50 else "[green]SUCCESS"
+                )
+            return table
+
+
+
         @app.callback(invoke_without_command=True)
         def _command(
             service: str = typer.Argument(None, show_default=False,help='AWS Service Name'),
         ):
             data = self.get_data(service=service)
 
-            layout = Layout()
-            layout.split_column(
-                Layout(name="upper"),
-                Layout(name="lower")
-            )            
-            console.print(layout)
-            console.print(data)
+            # layout = Layout()
+            # layout.split_column(
+            #     Layout(name="upper"),
+            #     Layout(name="lower")
+            # )            
+            # console.print(layout)
+            # console.print(data)
+            with Live(generate_table(), refresh_per_second=4) as live:
+                for _ in range(40):
+                    time.sleep(0.4)
+                    live.update(generate_table())
         return app
                 
     
